@@ -1,6 +1,9 @@
 # coding: utf-8
 
-from cms.plugins.text.models import AbstractText
+try:
+    from cms.plugins.text.models import AbstractText
+except ImportError:
+    from djangocms_text_ckeditor.models import AbstractText
 from django.db.models import CharField
 from django.utils.translation import ugettext_lazy as _
 
@@ -12,3 +15,4 @@ class Footnote(AbstractText):
     class Meta:
         verbose_name = _('Footnote')
         verbose_name_plural = _('Footnotes')
+        db_table = 'cmsplugin_footnote'
